pub async fn create_ref_internal(
app: &App,
tn_id: TnId,
params: CreateRefInternalParams<'_>,
) -> ClResult<(String, String)>Expand description
Internal API function to create a ref programmatically
This is a helper function for internal use (not an HTTP endpoint). It creates a ref with the given parameters and returns the ref_id and full URL.
Arguments
app- Application statetn_id- Tenant IDparams- Parameters for creating the reference
Returns
ref_id- The generated reference IDurl- The complete URL for the reference